@@ -616,8 +616,8 @@ my $StandardCode = {
     '5.6.8'  => 'contenterror', # UTF-8 string reply is required, but not permitted by the SMTP client
     '5.6.9'  => 'contenterror', # UTF-8 header message cannot be transferred to one or more recipients
     '5.7.0'  => 'securityerror',# Other or undefined security status
-    '5.7.1'  => 'blocked',      # Delivery not authorized, message refused
-    '5.7.2'  => 'blocked',      # Mailing list expansion prohibited
+    '5.7.1'  => 'securityerror',# Delivery not authorized, message refused
+    '5.7.2'  => 'securityerror',# Mailing list expansion prohibited
     '5.7.3'  => 'securityerror',# Security conversion required but not possible
     '5.7.4'  => 'securityerror',# Security features not supported
     '5.7.5'  => 'securityerror',# Cryptographic failure
@@ -671,30 +671,32 @@ my $InternalCode = {
         'undefined'    => '4.0.900',
     },
     'permanent' => {
-        'blocked'      => '5.0.971',
-        'contenterror' => '5.0.960',
-        'exceedlimit'  => '5.0.923',
-        'expired'      => '5.0.947',
-        'filtered'     => '5.0.910',
-        'hasmoved'     => '5.0.916',
-        'hostunknown'  => '5.0.912',
-        'mailboxfull'  => '5.0.922',
-        'mailererror'  => '5.0.939',
-        'mesgtoobig'   => '5.0.934',
-        'networkerror' => '5.0.944',
-        'norelaying'   => '5.0.909',
-        'notaccept'    => '5.0.932',
-        'onhold'       => '5.0.901',
-        'rejected'     => '5.0.918',
-        'securityerror'=> '5.0.970',
-        'spamdetected' => '5.0.980',
-        'suspend'      => '5.0.921',
-        'systemerror'  => '5.0.930',
-        'systemfull'   => '5.0.931',
-        'syntaxerror'  => '5.0.902',
-        'toomanyconn'  => '5.0.945',
-        'userunknown'  => '5.0.911',
-        'undefined'    => '5.0.900',
+        'blocked'        => '5.0.971',
+        'contenterror'   => '5.0.960',
+        'exceedlimit'    => '5.0.923',
+        'expired'        => '5.0.947',
+        'filtered'       => '5.0.910',
+        'hasmoved'       => '5.0.916',
+        'hostunknown'    => '5.0.912',
+        'mailboxfull'    => '5.0.922',
+        'mailererror'    => '5.0.939',
+        'mesgtoobig'     => '5.0.934',
+        'networkerror'   => '5.0.944',
+        'norelaying'     => '5.0.909',
+        'notaccept'      => '5.0.932',
+        'onhold'         => '5.0.901',
+        'policyviolation'=> '5.0.972',
+        'rejected'       => '5.0.918',
+        'securityerror'  => '5.0.970',
+        'spamdetected'   => '5.0.980',
+        'suspend'        => '5.0.921',
+        'systemerror'    => '5.0.930',
+        'systemfull'     => '5.0.931',
+        'syntaxerror'    => '5.0.902',
+        'toomanyconn'    => '5.0.945',
+        'userunknown'    => '5.0.911',
+        'undefined'      => '5.0.900',
+        'virusdetected'  => '5.0.971',
     },
 };
 
